
// Bundle of types from "backfill-config" and packages it references.
// This file was generated by dts-bundle-generator and packages/lage/scripts/update-dts-bundle.js

import { Readable } from 'stream';

declare const logLevelsObject: {
	silly: number;
	verbose: number;
	info: number;
	warn: number;
	error: number;
	mute: number;
};
declare type LogLevel = keyof typeof logLevelsObject;
declare type ConsoleLogger = {
	silly(...args: string[]): void;
	verbose(...args: string[]): void;
	info(...args: string[]): void;
	warn(...args: string[]): void;
	error(...args: string[]): void;
};
declare type Times = "hashTime" | "buildTime" | "putTime" | "fetchTime";
declare type Logger = ConsoleLogger & {
	setName(name: string): void;
	setHash(hash: string): void;
	setCacheProvider(cacheProvider: string): void;
	setHit(hit: boolean): void;
	setTime(type: Times): {
		stop(): void;
	};
	setMode(mode: string, logLevel: "verbose" | "info"): void;
	setHashOfOutput(hash: string): void;
	toFile(logFolder: string): Promise<void>;
	pipeProcessOutput(stdout: Readable | null, stderr: Readable | null): void;
};
interface AbortSignalLike {
	/**
	 * Indicates if the signal has already been aborted.
	 */
	readonly aborted: boolean;
	/**
	 * Add new "abort" event listener, only support "abort" event.
	 */
	addEventListener(type: "abort", listener: (this: AbortSignalLike, ev: any) => any, options?: any): void;
	/**
	 * Remove "abort" event listener, only support "abort" event.
	 */
	removeEventListener(type: "abort", listener: (this: AbortSignalLike, ev: any) => any, options?: any): void;
}
declare interface AccessToken {
	/**
	 * The access token returned by the authentication service.
	 */
	token: string;
	/**
	 * The access token's expiration timestamp in milliseconds, UNIX epoch time.
	 */
	expiresOnTimestamp: number;
}
declare interface GetTokenOptions {
	/**
	 * The signal which can be used to abort requests.
	 */
	abortSignal?: AbortSignalLike;
	/**
	 * Options used when creating and sending HTTP requests for this operation.
	 */
	requestOptions?: {
		/**
		 * The number of milliseconds a request can take before automatically being terminated.
		 */
		timeout?: number;
	};
	/**
	 * Options used when tracing is enabled.
	 */
	tracingOptions?: {
		/**
		 * Tracing Context for the current request.
		 */
		tracingContext?: TracingContext;
	};
	/**
	 * Allows specifying a tenantId. Useful to handle challenges that provide tenant Id hints.
	 */
	tenantId?: string;
	/**
	 * Claim details to perform the Continuous Access Evaluation authentication flow
	 */
	claims?: string;
}
declare interface TokenCredential {
	/**
	 * Gets the token provided by this credential.
	 *
	 * This method is called automatically by Azure SDK client libraries. You may call this method
	 * directly, but you must also handle token caching and token refreshing.
	 *
	 * @param scopes - The list of scopes for which the token will have access.
	 * @param options - The options used to configure any requests this
	 *                TokenCredential implementation might make.
	 */
	getToken(scopes: string | string[], options?: GetTokenOptions): Promise<AccessToken | null>;
}
declare interface TracingContext {
	/**
	 * Get a value from the context.
	 *
	 * @param key - key which identifies a context value
	 */
	getValue(key: symbol): unknown;
	/**
	 * Create a new context which inherits from this context and has
	 * the given key set to the given value.
	 *
	 * @param key - context key for which to set the value
	 * @param value - value to set for the given key
	 */
	setValue(key: symbol, value: unknown): TracingContext;
	/**
	 * Return a new context which inherits from this context but does
	 * not contain a value for the given key.
	 *
	 * @param key - context key for which to clear a value
	 */
	deleteValue(key: symbol): TracingContext;
}
export interface ICacheStorage {
	fetch: (hash: string) => Promise<boolean>;
	put: (hash: string, filesToCache: string[]) => Promise<void>;
}
export declare type AzureBlobCacheStorageOptions = {
	connectionString: string;
	container: string;
	maxSize?: number;
	credential?: TokenCredential;
};
export declare type NpmCacheStorageOptions = {
	npmPackageName: string;
	registryUrl: string;
	npmrcUserconfig?: string;
};
export declare type AzureBlobCacheStorageConfig = {
	provider: "azure-blob";
	options: AzureBlobCacheStorageOptions;
};
export declare type NpmCacheStorageConfig = {
	provider: "npm";
	options: NpmCacheStorageOptions;
};
export declare type CustomStorageConfig = {
	provider: (logger: Logger, cwd: string) => ICacheStorage;
	name?: string;
};
export declare type CacheStorageConfig = {
	provider: "local";
} | {
	provider: "local-skip";
} | NpmCacheStorageConfig | AzureBlobCacheStorageConfig | CustomStorageConfig;
export declare function getNpmConfigFromSerializedOptions(options: string, logger: Logger): NpmCacheStorageConfig;
export declare function getAzureBlobConfigFromSerializedOptions(options: string, logger: Logger): AzureBlobCacheStorageConfig;
export declare function getEnvConfig(logger: Logger): Partial<Config>;
export declare type HashGlobs = string[];
export declare const modesObject: {
	READ_ONLY: string;
	WRITE_ONLY: string;
	READ_WRITE: string;
	PASS: string;
};
export declare type BackfillModes = keyof typeof modesObject;
export declare type Config = {
	cacheStorageConfig: CacheStorageConfig;
	clearOutput: boolean;
	internalCacheFolder: string;
	logFolder: string;
	logLevel: LogLevel;
	name: string;
	mode: BackfillModes;
	outputGlob: string[];
	packageRoot: string;
	performanceReportName?: string;
	producePerformanceLogs: boolean;
	validateOutput: boolean;
	incrementalCaching: boolean;
};
export declare function isCorrectMode(mode: string): mode is BackfillModes;
export declare function getName(packageRoot: string): any;
export declare function getSearchPaths(fromPath: string): string[];
export declare function createDefaultConfig(fromPath: string): Config;
export declare function createConfig(logger: Logger, fromPath: string): Config;

export {};
